courses.EnrolmentsByOption (Enrolments using this option) — amici1

# `courses.EnrolmentsByOption` (Enrolments using this option)

Detail fields

- `<Panel main_1 in lino_xl.lib.courses.desktop.EnrolmentDetail on lino_xl.lib.courses.desktop.Enrolments>`

- `<Panel main_2 in lino_xl.lib.courses.desktop.EnrolmentDetail on lino_xl.lib.courses.desktop.Enrolments>`

- `<Panel main_3 in lino_xl.lib.courses.desktop.EnrolmentDetail on lino_xl.lib.courses.desktop.Enrolments>`

- Confirmation details (confirmation_details) : See `<lino.core.fields.RichTextField: confirmation_details>`.

Actions

Filter parameters

- `<django.db.models.fields.related.ForeignKey: author>`

- `<lino.core.choicelists.ChoiceListField: state>`

- `<lino.core.choicelists.ChoiceListField: course_state>`

- `<django.db.models.fields.BooleanField: participants_only>`

- `<django.db.models.fields.DateField: start_date>`

- `<django.db.models.fields.DateField: end_date>`

- `<django.db.models.fields.related.ForeignKey: user>`

## Filter parameters